@@ -3,10 +3,14 @@
 Can probably be replaced by types.SimpleNamespace from Python 3.3
 """
 
+from __future__ import annotations
+
+from typing import Any, Dict
+
 __all__ = ["Struct"]
 
 
-class Struct(dict):
+class Struct(Dict[Any, Any]):
     """A dict subclass with attribute style access.
 
     This dict subclass has a a few extra features:
@@ -87,7 +91,7 @@ class Struct(dict):
         you can't set a class member
         """
         # If key is an str it might be a class member or instance var
-        if isinstance(key, str):
+        if isinstance(key, str):  # noqa: SIM102
             # I can't simply call hasattr here because it calls getattr, which
             # calls self.__getattr__, which returns True for keys in
             # self._data.  But I only want keys in the class and in
@@ -181,7 +185,7 @@ class Struct(dict):
         >>> s1
         {'b': 30}
         """
-        for k in other.keys():
+        for k in other:
             if k in self:
                 del self[k]
         return self
@@ -195,7 +199,7 @@ class Struct(dict):
         outdict = {}
         for k, lst in data.items():
             if isinstance(lst, str):
-                lst = lst.split()
+                lst = lst.split()  # noqa: PLW2901
             for entry in lst:
                 outdict[entry] = k
         return outdict
@@ -330,11 +334,11 @@ class Struct(dict):
 
         # policies for conflict resolution: two argument functions which return
         # the value that will go in the new struct
-        preserve = lambda old, new: old  # noqa
-        update = lambda old, new: new  # noqa
-        add = lambda old, new: old + new  # noqa
-        add_flip = lambda old, new: new + old  # noqa  # note change of order!
-        add_s = lambda old, new: old + " " + new  # noqa
+        preserve = lambda old, new: old
+        update = lambda old, new: new
+        add = lambda old, new: old + new
+        add_flip = lambda old, new: new + old  # note change of order!
+        add_s = lambda old, new: old + " " + new
 
         # default policy is to keep current keys when there's a conflict
         conflict_solve = dict.fromkeys(self, preserve)
@@ -352,7 +356,7 @@ class Struct(dict):
                 ("add_flip", add_flip),
                 ("add_s", add_s),
             ]:
-                if name in inv_conflict_solve_user.keys():
+                if name in inv_conflict_solve_user:
                     inv_conflict_solve_user[func] = inv_conflict_solve_user[name]
                     del inv_conflict_solve_user[name]
             conflict_solve.update(self.__dict_invert(inv_conflict_solve_user))
